@@ -92,9 +92,8 @@ def execute_subprocess(
     return proxyresults
 
 
-
 def execute_subprocess_multiple_commands(
-    cmd: str, subcommands:list, exit_keys: str = "ctrl+x", end_of_printline: str = ""
+    cmd: str, subcommands: list, exit_keys: str = "ctrl+x", end_of_printline: str = ""
 ) -> list:
     popen = None
 
@@ -140,7 +139,7 @@ def execute_subprocess_multiple_commands(
                 stdout=subprocess.PIPE,
                 universal_newlines=True,
                 stderr=None,
-                shell=False,
+                shell=True,
             )
 
             for stdout_line in iter(popen.stdout.readline, ""):
@@ -187,3 +186,103 @@ def execute_subprocess_multiple_commands(
         except Exception:
             pass
     return proxyresults
+
+
+def execute_subprocess_multiple_commands_v2(
+    cmd: str, subcommands: list, exit_keys: str = "ctrl+x", end_of_printline: str = ""
+) -> list:
+    popen = None
+
+    def run_subprocess(cmd):
+        nonlocal popen
+
+        def kill_process():
+            nonlocal popen
+            try:
+                print("Killing the process")
+                p = psutil.Process(popen.pid)
+                p.kill()
+                try:
+                    if exit_keys in keyboard__.__dict__["_hotkeys"]:
+                        keyboard__.remove_hotkey(exit_keys)
+                except Exception:
+                    try:
+                        keyboard__.unhook_all_hotkeys()
+                    except Exception:
+                        pass
+            except Exception:
+                try:
+                    keyboard__.unhook_all_hotkeys()
+                except Exception:
+                    pass
+
+        if exit_keys not in keyboard__.__dict__["_hotkeys"]:
+
+            keyboard__.add_hotkey(exit_keys, kill_process)
+
+        try:
+            popen = subprocess.Popen(
+                cmd,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                universal_newlines=True,
+                stderr=None,
+                shell=False,
+            )
+
+            for subcommand in subcommands:
+                if isinstance(subcommand, bytes):
+                    subcommand = subcommand.rstrip(b"\n") + b"\n"
+
+                    subcommand = subcommand.deencode("utf-8", "replace")
+                else:
+                    subcommand = subcommand.rstrip("\n") + "\n"
+
+                popen.stdin.write(subcommand)
+
+            popen.stdin.close()
+
+            for stdout_line in iter(popen.stdout.readline, ""):
+                try:
+                    yield stdout_line
+                except Exception as Fehler:
+                    continue
+            popen.stdout.close()
+            return_code = popen.wait()
+        except Exception as Fehler:
+            print(Fehler)
+            try:
+                popen.stdout.close()
+                return_code = popen.wait()
+            except Exception as Fehler:
+                yield ""
+
+    proxyresults = []
+    try:
+        for proxyresult in run_subprocess(cmd):
+            proxyresults.append(proxyresult)
+            print(proxyresult, end=end_of_printline)
+    except BaseException:
+        try:
+            p = psutil.Process(popen.pid)
+            p.kill()
+            popen = None
+        except Exception as da:
+            print(da)
+
+    try:
+        if popen is not None:
+            p = psutil.Process(popen.pid)
+            p.kill()
+    except Exception as da:
+        pass
+
+    try:
+        if exit_keys in keyboard__.__dict__["_hotkeys"]:
+            keyboard__.remove_hotkey(exit_keys)
+    except Exception:
+        try:
+            keyboard__.unhook_all_hotkeys()
+        except Exception:
+            pass
+    return proxyresults
